Gaussian process regression fitting — BAGO 0.0.1 documentation

# Gaussian process regression fitting

The Gaussian process regression fitting is implemented in the `gpModel` class. You have to generate a search space before fitting the model.

fit(self, X, y)

  Function to fit the data to Gaussian process regression model.

  Parameters:

    - X – numpy array. Training data, input.

    - y – numpy array. Training data, output.

To use this function:

    # You need a gpModel object (d) with a search space defined.

    d.fit(X, y)